#
# Tcl script to download third-party libraries from canonical sources.
#
# Usage:
#	tclsh fetch.tcl
#

package require http

variable sources {
    http://www.gzip.org/zlib/zlib-1.2.1.tar.gz
    http://www.ijg.org/files/jpegsrc.v6b.tar.gz
    http://unc.dl.sourceforge.net/sourceforge/libpng/libpng-1.2.8-config.tar.gz
    http://dl.maptools.org/dl/libtiff/tiff-3.7.0.tar.gz
} 

# download url fp --
#	Fetch $url via HTTP and save contents in channel $fp
#
proc download {url fp} {
    set token [http::geturl $url -binary true -channel $fp]
    if {[http::ncode $token] ne 200} {
	set result [http::code $token]
	http::cleanup $token 
	return -code error $result
    }
    http::cleanup $token
    return "OK"
}


foreach url $sources {
    set filename [file tail $url]

    puts -nonewline "fetching $url... " ; flush stdout
    if {[file exists $filename]} {
    	puts "already fetched."
	continue;
    }

    set fpout [open $filename w]
    fconfigure $fpout -encoding binary
    set status [catch {download $url $fpout} msg]
    close $fpout
    puts $msg
    
    if {$status != 0} {
	file delete $filename
    }
}

#*EOF*
